@@ -489,7 +489,6 @@ class DrivenDownDoc(object):
 
     def feed_line(self, line, from_filepath):
         line = line.rstrip()
-        # print '| '+line
         if line.startswith('% '):
             if not self.title:
                 self.title = line[2:].strip()
@@ -551,20 +550,36 @@ def title2filename(title):
     return filename_safe.lower()
 
 
-def initialize(doc_filepath, print_feed=False):
+def initialize(doc_filepath, debug_output=None):
+    print_feed=False
+    line_feed=False
+    file_feed=False
+    if debug_output == 'line_feed':
+        line_feed=True
+    elif debug_output == 'file_feed':
+        file_feed=True
+    elif debug_output == 'file_line_feed':
+        print_feed=True
+    else:
+        print 'Unrecognized debug_output selection.'
+        print 'Must be one of: "line_feed", "file_feed", or "file_line_feed"'
+        print 'continuing with no debug_output'
+
     if print_feed:
         print '@@@@@@@@@@@@@@@@@@@@@@@@@ DDD FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
     global driven_down_doc
     driven_down_doc = DrivenDownDoc()
     root_dir, basename = os.path.split(doc_filepath)
-    feed_file(driven_down_doc, doc_filepath, root_dir, print_feed, rcrsn_lvl=0)
+    feed_file(driven_down_doc, doc_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0)
     if print_feed:
         print '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@'
 
 
 link_to_file_pattern = '(^%# (\w+.*)|^#### ((config|predict|response|runtime|status)/\w+.*))'
 regex = re.compile(link_to_file_pattern)
-def feed_file(driven_down_doc, filepath, root_dir, print_feed, rcrsn_lvl=0):
+def feed_file(driven_down_doc, filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0):
+    if file_feed:
+        print 'docdriven: '+filepath
     filename = os.path.basename(filepath)
     from_filekey = filename[:filename.rfind('.')] # last index of .
     feeder_file = open(filepath, 'r')
@@ -583,22 +598,24 @@ def feed_file(driven_down_doc, filepath, root_dir, print_feed, rcrsn_lvl=0):
                 path = 'chapter/'+path
             include_filepath = os.path.join(root_dir, path)
             if match.groups()[3] is not None:
-                feed_line(driven_down_doc, ('#### '+match.groups()[3]+'\n'), from_filekey, print_feed, rcrsn_lvl+1)
+                feed_line(driven_down_doc, ('#### '+match.groups()[3]+'\n'), from_filekey, line_feed, print_feed, rcrsn_lvl+1)
                 if match.groups()[3] == 'runtime':
-                    feed_line(driven_down_doc, ('~'*42)+'  python\n', from_filekey, print_feed, rcrsn_lvl+1)
+                    feed_line(driven_down_doc, ('~'*42)+'  python\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
                 else:
-                    feed_line(driven_down_doc, ('~'*44)+'  json\n', from_filekey, print_feed, rcrsn_lvl+1)
-                feed_file(driven_down_doc, include_filepath, root_dir, print_feed, rcrsn_lvl+1)
-                feed_line(driven_down_doc, ('~'*50)+'\n', from_filekey, print_feed, rcrsn_lvl+1)
+                    feed_line(driven_down_doc, ('~'*44)+'  json\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
+                feed_file(driven_down_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
+                feed_line(driven_down_doc, ('~'*50)+'\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
             else:
-                feed_file(driven_down_doc, include_filepath, root_dir, print_feed, rcrsn_lvl+1)
+                feed_file(driven_down_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
         else:
-            feed_line(driven_down_doc, line, from_filekey, print_feed, rcrsn_lvl)
+            feed_line(driven_down_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl)
     feeder_file.close()
 
-def feed_line(driven_down_doc, line, from_filekey, print_feed, rcrsn_lvl):
+def feed_line(driven_down_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
     if print_feed:
-        print ' '*(4*rcrsn_lvl)+'| '+line,
+        print ' '*(4*rcrsn_lvl)+'| '+line
+    if line_feed:
+        print 'docdriven:   '+line
     driven_down_doc.feed_line(line, from_filekey)
 
 def print_to_files(parent_dirpath, ddd_all_response=True):
